{%- if filetype_loop == 0 %}Compliance Type,Status,State,Last Sync Time,Last Update Time,Message,Additional Data URL
{%- for item in compliance %}
{{ item.complianceType }},{{ item.status }},{{ item.state }},{{ item.lastSyncTime }},{{ item.lastUpdateTime }},{%-     if item.message %}{{ item.message }},{%-     else %}N/A,{%-     endif %}{%-     if item.additionalDataURL %}{{ item.additionalDataURL }}{%-     else %}N/A{%-     endif %}
{%- endfor %}
{%- else %}
{%-     if filetype_loop == 1 %}
# Compliance
| Compliance Type | Status | State | Last Sync Time | Last Update Time | Message | Additional Data URL |
| --------------- | ------ | ----- | -------------- | ---------------- | ------- | -------------------
{%- for item in compliance %}
| {{ item.complianceType }} | {{ item.status }} | {{ item.state }} | {{ item.lastSyncTime }} | {{ item.lastUpdateTime }} | {%-     if item.message %}{{ item.message }} | {%-     else %}N/A | {%-     endif %}{%-     if item.additionalDataURL %}{{ item.additionalDataURL }}{%-     else %}N/A{%-     endif %} |
{%- endfor %}
{%-     else %}
{%-         if filetype_loop == 2 %}
<html>
<head>
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <script src="https://cdn.datatables.net/1.11.4/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/dataTables.buttons.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jszip/3.1.3/jszip.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/pdfmake.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/vfs_fonts.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.html5.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.print.min.js"></script>
    <script src="https://cdn.datatables.net/colreorder/1.5.4/js/dataTables.colReorder.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.colVis.min.js"></script>
    <script src="https://cdn.datatables.net/keytable/2.6.4/js/dataTables.keyTable.min.js"></script>
    <script src="https://cdn.datatables.net/select/1.3.3/js/dataTables.select.min.js"></script>
    <script src="https://cdn.datatables.net/fixedheader/3.1.9/js/dataTables.fixedHeader.min.js"></script>
    <link rel="stylesheet" href="https://cdn.datatables.net/fixedheader/3.1.9/css/fixedHeader.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/select/1.3.3/css/select.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/keytable/2.6.4/css/keyTable.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/1.11.4/css/jquery.dataTables.min.css">
</head>
<body>
<h1>DNAC </h1>
<table id = "compliance">
  <thead>
    <tr>
      <th>Compliance Type</th>
      <th>Status</th>
      <th>State</th>
      <th>Last Sync Time</th>
      <th>Last Update Time</th>
      <th>Message</th>
      <th>Additional Data URL</th>
    </tr>
  </thead>
  <tbody>
{%- for item in compliance %}
  {%                if loop.index is divisibleby 2 %}
  <tr style='background-color:#ddd'>
  {%-               endif %}
    <td>{{ item.complianceType }}</td>
    <td>{{ item.status }}</td>
    <td>{{ item.state }}</td>
    <td>{{ item.lastSyncTime }}</td>
    <td>{{ item.lastUpdateTime }}</td>
    <td>{%-     if item.message %}{{ item.message }}{%-     else %}N/A{%-     endif %}</td>
    <td>{%-     if item.additionalDataURL %}{{ item.additionalDataURL }}{%-     else %}N/A{%-     endif %}</td>
  </tr>
{%- endfor %}
  </tbody>
</table>
<script type = "text/javascript">
  $(document).ready(function(){
    $('#compliance thead tr')
    .clone(true)
    .addClass('filters')
    .appendTo('#compliance thead');

    var table = $('#compliance').DataTable({
        keys: true,
        dom: 'Bfrtip',
        lengthMenu: [
            [ 10, 25, 50, -1 ],
            [ '10 rows', '25 rows', '50 rows', 'Show all' ]
        ],
        buttons: [
        'pageLength','colvis','copy', 'csv', 'excel', 'pdf', 'print'
        ],
        colReorder: true,
        select: true,            
        orderCellsTop: true,
        fixedHeader: true,
        initComplete: function () {
        var api = this.api();

        // For each column
        api
            .columns()
            .eq(0)
            .each(function (colIdx) {
                // Set the header cell to contain the input element
                var cell = $('.filters th').eq(
                    $(api.column(colIdx).header()).index()
                );
                var title = $(cell).text();
                $(cell).html('<input type="text" placeholder="' + title + '" />');

                // On every keypress in this input
                $(
                    'input',
                    $('.filters th').eq($(api.column(colIdx).header()).index())
                )
                    .off('keyup change')
                    .on('keyup change', function (e) {
                        e.stopPropagation();

                        // Get the search value
                        $(this).attr('title', $(this).val());
                        var regexr = '({search})'; //$(this).parents('th').find('select').val();

                        var cursorPosition = this.selectionStart;
                        // Search the column for that value
                        api
                            .column(colIdx)
                            .search(
                                this.value != ''
                                    ? regexr.replace('{search}', '(((' + this.value + ')))')
                                    : '',
                                this.value != '',
                                this.value == ''
                            )
                            .draw();

                        $(this)
                            .focus()[0]
                            .setSelectionRange(cursorPosition, cursorPosition);
                    });
            });
    },
});
});        
</script>   
</body></html>
{%-         else %}
# Compliance
{%- for item in compliance %}
## {{ item.complianceType }}
### Status: {{ item.status }}
### State: {{ item.state }}
### Last Contact
#### Sync: {{ item.lastSyncTime }}
#### Update: {{ item.lastUpdateTime }}
{%-     if item.message %}
### Message: {{ item.message }}
{%-     endif %}
{%-     if item.additionalDataURL %}
### [Additional Info]({{ item.additionalDataURL }})
{%-     endif %}
{%- endfor %}
{%-         endif %}
{%-     endif %}
{%- endif %}